﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using MySql.Data.MySqlClient;

namespace MontoyaTech.MySqlPlus
{
    /// <summary>
    /// The outline of a MySqlCommandException.
    /// </summary>
    public class MySqlCommandException : Exception
    {
        /// <summary>
        /// The MySqlCommand that failed to execute.
        /// </summary>
        public MySqlCommand Command = null;

        /// <summary>
        /// Creates a new MySqlCommandException with a command.
        /// </summary>
        /// <param name="command"></param>
        public MySqlCommandException(MySqlCommand command) : base($"Failed to execute MySqlCommand. Query: {command.CommandText}")
        {
            this.Command = command;
        }

        /// <summary>
        /// Creates a new MySqlCommandException with a command and inner exception if any.
        /// </summary>
        /// <param name="command"></param>
        /// <param name="inner"></param>
        public MySqlCommandException(MySqlCommand command, Exception inner) : base($"Failed to execute MySqlCommand. Query: {command.CommandText}", inner)
        {
            this.Command = command;
        }
    }
}
